@@ -360,6 +360,22 @@ def register_transforms():
                                            source='FAFB14',
                                            target=None,
                                            transform_type='mirror')
+    # Add "FAFB" as synonym to "FAFB14" since this is as alias on the chart
+    transforms.registry.register_transform(transform=tr,
+                                           source='FAFB',
+                                           target=None,
+                                           transform_type='mirror')
+
+    # Add mirror transform for FlyWire
+    # These landmarks were created by xforming those for FAFB14 to FlyWire space
+    fp = os.path.join(data_filepath, 'FlyWire_mirror_landmarks.csv')
+    lm = pd.read_csv(fp)
+    tr = transforms.TPStransform(lm[['x_flip', 'y_flip', 'z_flip']].values,
+                                 lm[['x_mirr', 'y_mirr', 'z_mirr']].values)
+    transforms.registry.register_transform(transform=tr,
+                                           source='FLYWIRE',
+                                           target=None,
+                                           transform_type='mirror')
 
     # Add a simple symmetrization transform for FAFB14
     fp = os.path.join(data_filepath, 'FAFB14_symmetrize_landmarks_nm.csv')
